@@ -43,7 +43,7 @@ import adtlog
 known_restrictions = ['rw-build-tree', 'breaks-testbed', 'needs-root',
                       'build-needed', 'allow-stderr', 'isolation-container',
                       'isolation-machine', 'needs-recommends', 'needs-reboot',
-                      'flaky', 'skippable',
+                      'flaky', 'skippable', 'superficial',
                       'skip-not-installable']
 
 
@@ -128,7 +128,10 @@ class Test:
         '''Mark test as passed'''
 
         self.result = True
-        adtlog.report(self.name, 'PASS')
+        if 'superficial' in self.restrictions:
+            adtlog.report(self.name, 'PASS (superficial)')
+        else:
+            adtlog.report(self.name, 'PASS')
 
     def set_skipped(self, reason):
         '''Mark test as skipped'''
